# swmr_tools

[![PyPI release](https://img.shields.io/pypi/v/swmr-tools.svg)](https://pypi.org/project/swmr-tools/) [![Test status](https://github.com/DiamondLightSource/python-swmrtools/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/python-swmrtools/actions/workflows/ci.yml) [![Docs](https://readthedocs.org/projects/python-swmrtools/badge/?version=latest)](https://python-swmrtools.readthedocs.io/en/latest/?badge=latest)

swmr_tools is a Python library developed by Diamond Light Source Ltd designed to facilitate reading and processing data from HDF5 swmr files as they are being written.

## Installation

swmr_tools can be installed using either conda [(from the conda-forge channel)](https://anaconda.org/conda-forge/swmr-tools):

```bash
conda install -c conda-forge swmr-tools
```

or the package manager [pip](https://pip.pypa.io/en/stable/):

```bash
pip install swmr_tools
```

## Usage

- For full examples of use please see the full documentation at https://python-swmrtools.readthedocs.io

- Jupyter notebook tutorials for key functionality can be found in the tutorial directory in the git repository
